pub struct DefaultLayoutDirection(pub LayoutDirection);Expand description
Default writing direction for the application root. The
resolve_layout_direction system uses this when the root entity
has no explicit LayoutDirection. It defaults to
LayoutDirection::Ltr and nothing sets it from the locale today,
so a right-to-left app still needs dir="rtl" in its markup.
Tuple Fields
0: LayoutDirectionTrait Implementations
Sourceimpl Clone for DefaultLayoutDirection
impl Clone for DefaultLayoutDirection
Sourcefn clone(&self) -> DefaultLayoutDirection
fn clone(&self) -> DefaultLayoutDirection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for DefaultLayoutDirection
impl Component for DefaultLayoutDirection
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::SparseSet
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::SparseSet
A constant indicating the storage type used for this component.
Sourcetype Mutability = Mutable
type Mutability = Mutable
A marker type to assist Bevy with determining if this component is
mutable, or immutable. Mutable components will have
Component<Mutability = Mutable>,
while immutable components will instead have Component<Mutability = Immutable>. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Registers required components. Read more
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Called when registering this component, allowing to override clone function (or disable cloning altogether) for this component. Read more
Sourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
Returns [
ComponentRelationshipAccessor] required for working with relationships in dynamic contexts. Read morefn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
Maps the entities on this component using the given
EntityMapper. This is used to remap entities in contexts like scenes and entity cloning.
When deriving Component, this is populated by annotating fields containing entities with #[entities] Read moreSourceimpl Debug for DefaultLayoutDirection
impl Debug for DefaultLayoutDirection
Sourceimpl Default for DefaultLayoutDirection
impl Default for DefaultLayoutDirection
Sourceimpl Hash for DefaultLayoutDirection
impl Hash for DefaultLayoutDirection
Sourceimpl PartialEq for DefaultLayoutDirection
impl PartialEq for DefaultLayoutDirection
Sourcefn eq(&self, other: &DefaultLayoutDirection) -> bool
fn eq(&self, other: &DefaultLayoutDirection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for DefaultLayoutDirection
impl Eq for DefaultLayoutDirection
impl Resource for DefaultLayoutDirection
impl StructuralPartialEq for DefaultLayoutDirection